﻿using System.IO;
using Microsoft.AspNet.Builder;
using Microsoft.AspNet.Hosting;
using Microsoft.Framework.DependencyInjection;
using Microsoft.Data.Entity;
using Microsoft.Data.Entity.Infrastructure;
using WebApplication2.Data;
using Microsoft.Framework.Configuration;
using Microsoft.Framework.Configuration.Json;

namespace WebApplication2
{
    public class Startup
    {
        public Startup(IHostingEnvironment env)
        {
            var jsonConfig = new JsonConfigurationSource(Path.Combine(env.WebRootPath, "config.json"));
            jsonConfig.Load();
            IConfiguration configuration = new ConfigurationRoot(new IConfigurationSource[]
            {
                jsonConfig
            });
            Configuration = configuration;
        }

        public IConfiguration Configuration { get; set; }

        // This method gets called by a runtime.
        // Use this method to add services to the container
        public void ConfigureServices(IServiceCollection services)
        {
            services.AddMvc();

            services.AddEntityFramework()
                .AddRelational()
                .AddSqlServer()
                .AddDbContext<PersonContext>(options => options.UseSqlServer(Configuration["Data:DefaultConnection:ConnectionString"]));
        }

        // Configure is called after ConfigureServices is called.
        public void Configure(IApplicationBuilder app, IHostingEnvironment env)
        {
            // Configure the HTTP request pipeline.
            app.UseStaticFiles();

            // Add MVC to the request pipeline.
            app.UseMvc();

            using (var cxt = (PersonContext)app.ApplicationServices.GetService(typeof(PersonContext)))
            {
                cxt.Database.Migrate();
            }

        }
    }
}
